@@ -28,15 +28,14 @@ from inflector import English, Inflector
 
 from nark.helpers.dev.profiling import profile_elapsed
 
+from dob_bright.styling.style_conf import color as styling_color
+from dob_bright.styling.style_engine import StyleEngine
 from dob_bright.termio.errors import dob_been_warned_reset
 
+from dob_prompt.prompters.triple_prompter import ask_user_for_edits
+
 from dob_viewer.ptkui.re_confirm import confirm
 
-from ..config.styling.style_conf import color as styling_color
-from ..config.styling.style_engine import StyleEngine
-
-from ..crud.interrogate import ask_user_for_edits
-
 from ..ptkui.dialog_overlay import show_message
 
 from .action_manager import ActionManager
@@ -122,7 +121,7 @@ class Carousel(object):
 
     @property
     def async_enable(self):
-        assert(self._async_enable)  # 2020-02-01: Always True now because PTK3.
+        assert self._async_enable  # 2020-02-01: Always True now because PTK3.
         return self._async_enable
 
     @property
@@ -287,10 +286,15 @@ class Carousel(object):
             # No Facts edited.
             return True
         question = _('\nReally exit without saving?')
+        allow_mash_quit = self.controller.config['dev.allow_mash_quit']
         try:
-            confirmed = confirm(question, erase_when_done=True)
+            confirmed = confirm(
+                question,
+                erase_when_done=True,
+                allow_mash_quit=allow_mash_quit,
+            )
         except KeyboardInterrupt:
-            confirmed = True  # Eh?
+            confirmed = False
         return confirmed
 
     def process_save_early(self):
@@ -405,7 +409,7 @@ class Carousel(object):
             rerun = self.runloop_async()
             return rerun
         else:
-            assert(False)  # 2020-02-01: Dead path now because always async.
+            assert False  # 2020-02-01: Dead path now because always async.
             self.zone_manager.application.run()
             return False
 
@@ -507,7 +511,7 @@ class Carousel(object):
                 return False
             except Exception as err:
                 self.controller.client_logger.warning(
-                    _("Unexpected async err: {}").format(err),
+                    "Unexpected async err: {}".format(err),
                 )
             return True
 
@@ -614,7 +618,7 @@ class Carousel(object):
     def dev_breakpoint(self, event):
         if not self.controller.config['dev.catch_errors']:
             self.controller.client_logger.warning(
-                _('Please enable ‘dev.catch_errors’ to use live debugging.')
+                'Please enable ‘dev.catch_errors’ to use live debugging.'
             )
             return
         self.pdb_set_trace(event)
