@@ -37,8 +37,10 @@ from prompt_toolkit.output.color_depth import ColorDepth
 from prompt_toolkit.styles import Style
 from prompt_toolkit.widgets import Box, Label
 
-from ..crud.facts_diff import FactsDiff
+from dob_bright.crud.facts_diff import FactsDiff
+
 from ..ptkui.dialog_overlay import alert_and_question
+
 from .exceptions import catch_action_exception
 from .zone_content import ZoneContent
 from .zone_details import ZoneDetails
